@@ -1,19 +1,8 @@
-# -*- coding: utf-8 -*-
-#
-# Copyright (c) 2008-2009 Benoit Chesneau <benoitc@e-engura.com> 
-#
-# Permission to use, copy, modify, and distribute this software for any
-# purpose with or without fee is hereby granted, provided that the above
-# copyright notice and this permission notice appear in all copies.
-#
-# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
-# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
-# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
-# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
-# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
-# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
-# OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
+# -*- coding: utf-8 -
 #
+# This file is part of couchdbkit released under the MIT license. 
+# See the NOTICE for more information.
+
 __author__ = 'benoitc@e-engura.com (Benoît Chesneau)'
 
 import datetime
@@ -489,11 +478,11 @@ class DocumentTestCase(unittest.TestCase):
         a.save()
         
         text_attachment = "un texte attaché"
-        old_rev = a._rev
         
         a.put_attachment(text_attachment, "test", "text/plain")
         a.delete_attachment('test')
         self.assertRaises(ResourceNotFound, a.fetch_attachment, 'test')
+        self.assertFalse('test' in a._doc['_attachments'])
         
         self.server.delete_db('couchdbkit_test')
 
@@ -715,6 +704,18 @@ class PropertyTestCase(unittest.TestCase):
             a.i = "essai"
 
         self.assertRaises(BadValueError, bad_value)
+        
+    def testValueNone(self):
+        class A(Document):
+            s = StringProperty()
+        a = A()
+        a.s = None
+        self.assert_(a._doc['s'] is None)
+        A._db = self.db
+        a.save()
+        b = A.get(a._id)
+        self.assert_(b.s is None)
+        self.assert_(b._doc['s'] is None)
 
     def testSchemaBuild(self):
         schema = DocumentSchema(i = IntegerProperty())
@@ -947,6 +948,10 @@ class PropertyTestCase(unittest.TestCase):
         self.assert_(b1.ls == [u'hello', u'123'])
         self.assert_(b1._doc['ls'] == [u'hello', u'123'])
 
+        self.assert_(b1.ls.index(u'hello') == 0)
+        b1.ls.remove(u'hello')
+        self.assert_(u'hello' not in b1.ls)
+
          
     def testDictProperty(self):
         from datetime import datetime
